==> hs-haskeline-0.6.2.2.tbz: lib/haskeline-0.6.2.2/register.sh <==
#!/bin/sh

echo 'name: haskeline
version: 0.6.2.2
license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://trac.haskell.org/haskeline
package-url:
description: Haskeline provides a user interface for line input in command-line
             programs.  This library is similar in purpose to readline, but since
             it is written in Haskell it is (hopefully) more easily used in other
             Haskell programs.
             .
             Haskeline runs both on POSIX-compatible systems and on Windows.
category: User Interfaces
author: Judah Jacobson
exposed: True
exposed-modules: System.Console.Haskeline
                 System.Console.Haskeline.Completion
                 System.Console.Haskeline.Encoding
                 System.Console.Haskeline.MonadException
                 System.Console.Haskeline.History System.Console.Haskeline.IO
hidden-modules: System.Console.Haskeline.Backend.Posix
                System.Console.Haskeline.Backend.IConv
                System.Console.Haskeline.Backend.DumbTerm
                System.Console.Haskeline.Backend System.Console.Haskeline.Command
                System.Console.Haskeline.Command.Completion
                System.Console.Haskeline.Command.History
                System.Console.Haskeline.Command.KillRing
                System.Console.Haskeline.Directory System.Console.Haskeline.Emacs
                System.Console.Haskeline.InputT System.Console.Haskeline.Key
                System.Console.Haskeline.LineState System.Console.Haskeline.Monads
                System.Console.Haskeline.Prefs System.Console.Haskeline.RunCommand
                System.Console.Haskeline.Term System.Console.Haskeline.Command.Undo
                System.Console.Haskeline.Vi
import-dirs: /usr/local/lib/haskeline-0.6.2.2/ghc-6.10.4
library-dirs: /usr/local/lib/haskeline-0.6.2.2/ghc-6.10.4
              /usr/local/lib
hs-libraries: HShaskeline-0.6.2.2
extra-libraries: iconv
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/lib/haskeline-0.6.2.2/ghc-6.10.4/include
includes: h_iconv.h
depends: base-3.0.3.1 bytestring-0.9.1.4 containers-0.2.0.1
         directory-1.0.0.3 extensible-exceptions-0.1.1.0 filepath-1.1.0.2
         mtl-1.1.0.2 unix-2.3.2.0 utf8-string-0.3.6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/haskeline-0.6.2.2/html/haskeline.haddock
haddock-html: /usr/local/share/doc/haskeline-0.6.2.2/html' | /usr/local/bin/ghc-pkg update -

==> hs-haskeline-0.6.2.3.tbz: lib/haskeline-0.6.2.3/register.sh <==
#!/bin/sh

echo 'name: haskeline
version: 0.6.2.3
license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://trac.haskell.org/haskeline
package-url:
description: Haskeline provides a user interface for line input in command-line
             programs.  This library is similar in purpose to readline, but since
             it is written in Haskell it is (hopefully) more easily used in other
             Haskell programs.
             .
             Haskeline runs both on POSIX-compatible systems and on Windows.
category: User Interfaces
author: Judah Jacobson
exposed: True
exposed-modules: System.Console.Haskeline
                 System.Console.Haskeline.Completion
                 System.Console.Haskeline.Encoding
                 System.Console.Haskeline.MonadException
                 System.Console.Haskeline.History System.Console.Haskeline.IO
hidden-modules: System.Console.Haskeline.Backend.WCWidth
                System.Console.Haskeline.Backend.Posix
                System.Console.Haskeline.Backend.IConv
                System.Console.Haskeline.Backend.DumbTerm
                System.Console.Haskeline.Backend System.Console.Haskeline.Command
                System.Console.Haskeline.Command.Completion
                System.Console.Haskeline.Command.History
                System.Console.Haskeline.Command.KillRing
                System.Console.Haskeline.Directory System.Console.Haskeline.Emacs
                System.Console.Haskeline.InputT System.Console.Haskeline.Key
                System.Console.Haskeline.LineState System.Console.Haskeline.Monads
                System.Console.Haskeline.Prefs System.Console.Haskeline.RunCommand
                System.Console.Haskeline.Term System.Console.Haskeline.Command.Undo
                System.Console.Haskeline.Vi
import-dirs: /usr/local/lib/haskeline-0.6.2.3/ghc-6.10.4
library-dirs: /usr/local/lib/haskeline-0.6.2.3/ghc-6.10.4
              /usr/local/lib
hs-libraries: HShaskeline-0.6.2.3
extra-libraries: iconv
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/lib/haskeline-0.6.2.3/ghc-6.10.4/include
includes: h_iconv.h
depends: base-3.0.3.1 bytestring-0.9.1.4 containers-0.2.0.1
         directory-1.0.0.3 extensible-exceptions-0.1.1.0 filepath-1.1.0.2
         mtl-1.1.0.2 unix-2.3.2.0 utf8-string-0.3.6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/haskeline-0.6.2.3/html/haskeline.haddock
haddock-html: /usr/local/share/doc/haskeline-0.6.2.3/html' | /usr/local/bin/ghc-pkg update -
